@@ -10,7 +10,7 @@ import functools
 import json
 import logging
 import warnings
-from abc import ABCMeta, abstractmethod, abstractproperty
+from abc import ABCMeta, abstractmethod
 from inspect import isabstract
 from pathlib import Path
 from typing import (
@@ -34,7 +34,7 @@ from ..grids.cartesian import CartesianGridBase
 from ..tools.cache import cached_method
 from ..tools.docstrings import fill_in_docstring
 from ..tools.misc import Number, number_array
-from ..tools.numba import jit, make_array_constructor
+from ..tools.numba import jit, make_array_constructor, numba_dict
 from ..tools.plotting import (
     PlotReference,
     napari_add_layers,
@@ -156,9 +156,11 @@ class FieldBase(metaclass=ABCMeta):
     @property
     def _data_flat(self) -> np.ndarray:
         """:class:`~numpy.ndarray`: flat version of discretized data with ghost cells"""
-        # flatten the first dimension of the internal data
-        full_shape = tuple(s + 2 for s in self.grid.shape)
-        return self._data_full.reshape(-1, *full_shape)
+        # flatten the first dimension of the internal data by creating a view and then
+        # setting the new shape. This disallows accidental copying of the data
+        data_flat = self._data_full.view()
+        data_flat.shape = (-1, *self.grid._shape_full)
+        return data_flat
 
     @_data_flat.setter
     def _data_flat(self, value: np.ndarray) -> None:
@@ -296,9 +298,6 @@ class FieldBase(metaclass=ABCMeta):
         Args:
             filename (str):
                 Path where the data is stored
-            metadata (dict):
-                A dictionary of additional information that is stored with the file.
-                Note that not all formats support metadata.
             \**kwargs:
                 Additional parameters may be supported for some formats
         """
@@ -360,11 +359,11 @@ class FieldBase(metaclass=ABCMeta):
         is_scalar = accept_scalar and isinstance(other, ScalarField)
         class_compatible = self.__class__ == other.__class__ or is_scalar
         if not class_compatible:
-            raise TypeError("Fields are incompatible")
+            raise TypeError(f"Fields {self} and {other} are incompatible")
 
         # check whether the associated grids are identical
         if not self.grid.compatible_with(other.grid):
-            raise ValueError("Grids incompatible")
+            raise ValueError(f"Grids {self.grid} and {other.grid} are incompatible")
 
     @property
     def dtype(self):
@@ -585,6 +584,14 @@ class FieldBase(metaclass=ABCMeta):
         """divide field by value"""
         return self._binary_operation(other, np.true_divide, scalar_second=True)
 
+    def __rtruediv__(self, other) -> FieldBase:
+        """divide field by value"""
+
+        def rdivision(x, y, **kwargs):
+            return np.true_divide(y, x, **kwargs)
+
+        return self._binary_operation(other, rdivision, scalar_second=True)
+
     def __itruediv__(self: TField, other) -> TField:
         """divide field by value"""
         return self._binary_operation_inplace(other, np.true_divide, scalar_second=True)
@@ -1186,7 +1193,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         # convert `fill` to dtype of data
         if fill is not None:
             if self.rank == 0:
-                fill = self.data.dtype.type(fill)
+                fill = self.data.dtype.type(fill)  # type: ignore
             else:
                 fill = np.broadcast_to(fill, self.data_shape).astype(self.data.dtype)
 
@@ -1504,7 +1511,8 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         bcs = self.grid.get_boundary_conditions(bc, rank=self.rank)
         bcs.set_ghost_cells(self._data_full, args=args)
 
-    @abstractproperty
+    @property
+    @abstractmethod
     def integral(self) -> NumberOrArray:
         pass
 
@@ -1565,6 +1573,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         out: Optional[DataFieldBase] = None,
         *,
         label: str = None,
+        args: Dict[str, Any] = None,
         **kwargs,
     ) -> DataFieldBase:
         r"""apply an operator and return result as a field
@@ -1606,7 +1615,9 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         else:
             # apply the operator with boundary conditions
             op_with_bcs = self.grid.make_operator(operator_info, bc=bc, **kwargs)
-            out.data[:] = op_with_bcs(self.data)
+
+            # we need to convert the python dict into a numba dict for compilation
+            out.data[:] = op_with_bcs(self.data, args=numba_dict(args))
 
         return out
 
