@@ -13,7 +13,7 @@ import itertools
 import json
 import logging
 import warnings
-from abc import ABCMeta, abstractmethod, abstractproperty
+from abc import ABCMeta, abstractmethod
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -269,7 +269,8 @@ class GridBase(metaclass=ABCMeta):
 
         return set_valid  # type: ignore
 
-    @abstractproperty
+    @property
+    @abstractmethod
     def state(self) -> Dict[str, Any]:
         pass
 
@@ -434,7 +435,8 @@ class GridBase(metaclass=ABCMeta):
         shape = shape_bndry + (self.num_axes,)
         return np.stack(points, -1).reshape(shape)
 
-    @abstractproperty
+    @property
+    @abstractmethod
     def volume(self) -> float:
         pass
 
@@ -681,7 +683,7 @@ class GridBase(metaclass=ABCMeta):
         operator: Union[str, OperatorInfo],
         bc: BoundariesData,
         **kwargs,
-    ) -> Callable[[np.ndarray], np.ndarray]:
+    ) -> Callable[..., np.ndarray]:
         """return a compiled function applying an operator with boundary conditions
 
         The returned function takes the discretized data on the grid as an input and
@@ -690,7 +692,8 @@ class GridBase(metaclass=ABCMeta):
         internally to apply the boundary conditions specified as `bc`. Note that the
         function supports an optional argument `out`, which if given should provide
         space for the valid output array without the ghost cells. The result of the
-        operator is then written into this output array.
+        operator is then written into this output array. The function also accepts an
+        optional parameter `args`, which is forwarded to `set_ghost_cells`.
 
         Args:
             operator (str):
@@ -704,7 +707,8 @@ class GridBase(metaclass=ABCMeta):
                 Specifies extra arguments influencing how the operator is created.
 
         Returns:
-            callable: the function that applies the operator
+            callable: the function that applies the operator. This function has the
+            signature (arr: np.ndarray, out: np.ndarray = None, args=None).
         """
         backend = kwargs.get("backend", "numba")  # numba is the default backend
 
@@ -719,21 +723,22 @@ class GridBase(metaclass=ABCMeta):
         shape_out = (self.dim,) * operator.rank_out + self.shape
 
         if backend == "numba":
-            # create a compiled function to apply to the operator
+            # create a compiled function to apply the operator
             set_ghost_cells = bcs.make_ghost_cell_setter()
-            get_valid = self._make_get_valid()
+            set_valid = self._make_set_valid()
 
             if not is_jitted(operator_raw):
                 operator_raw = jit(operator_raw)
 
             @jit_allocate_out(out_shape=shape_out)
-            def apply_op(arr: np.ndarray, out: np.ndarray = None) -> np.ndarray:
+            def apply_op(
+                arr: np.ndarray, out: np.ndarray = None, args=None
+            ) -> np.ndarray:
                 """applies operator to the data"""
                 # prepare input with boundary conditions
                 arr_full = np.empty(shape_in_full, dtype=arr.dtype)
-                arr_valid = get_valid(arr_full)
-                arr_valid[:] = arr
-                set_ghost_cells(arr_full)
+                set_valid(arr_full, arr)
+                set_ghost_cells(arr_full, args=args)
 
                 # apply operator
                 operator_raw(arr_full, out)  # type: ignore
@@ -742,20 +747,24 @@ class GridBase(metaclass=ABCMeta):
                 return out  # type: ignore
 
         elif backend in {"numpy", "scipy"}:
-            # create a numpy/scipy function to apply to the operator
+            # create a numpy/scipy function to apply the operator
 
-            def apply_op(arr: np.ndarray, out: np.ndarray = None) -> np.ndarray:
+            def apply_op(
+                arr: np.ndarray, out: np.ndarray = None, args=None
+            ) -> np.ndarray:
                 """set boundary conditions and apply operator"""
-                # prepare input with boundary conditions
-                arr_full = np.empty(shape_in_full, dtype=arr.dtype)
-                arr_full[(...,) + self._idx_valid] = arr
-                bcs.set_ghost_cells(arr_full)
-
-                # apply operator
+                # ensure result array is allocated
                 if out is None:
                     out = np.empty(shape_out, dtype=arr.dtype)
                 else:
                     assert out.shape == shape_out
+
+                # prepare input with boundary conditions
+                arr_full = np.empty(shape_in_full, dtype=arr.dtype)
+                arr_full[(...,) + self._idx_valid] = arr
+                bcs.set_ghost_cells(arr_full, args=args)
+
+                # apply operator
                 operator_raw(arr_full, out)
 
                 # return valid part of the output
