@@ -266,7 +266,7 @@ class CartesianGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
         """convert points given in Cartesian coordinates to this grid
 
         Args:
-            points (:class:`~numpy.ndarray`): Points in Cartesian coordinates.
+            coords (:class:`~numpy.ndarray`): Points in Cartesian coordinates.
 
         Returns:
             :class:`~numpy.ndarray`: Points given in the coordinates of the grid
@@ -493,7 +493,7 @@ class UnitGrid(CartesianGridBase):
             return np.zeros((0, self.dim))
         if cells.shape[-1] != self.dim:
             raise DimensionError(f"Array of shape {cells.shape} cannot denote cells")
-        return cells + 0.5
+        return cells + 0.5  # type: ignore
 
     def point_to_cell(self, points: np.ndarray) -> np.ndarray:
         """Determine cell(s) corresponding to given point(s)
