@@ -128,7 +128,7 @@ def test_operators():
     for grid in iter_grids():
         assert "laplace" in grid.operators
         with pytest.raises(ValueError):
-            grid.get_operator("not_existent", "natural")
+            grid.make_operator("not_existent", "natural")
         grid.register_operator("noop", make_op)
         assert "noop" in grid.operators
         del grid._operators["noop"]  # reset original state
