@@ -10,6 +10,9 @@ import re
 from typing import Any, Callable, Dict, Tuple
 
 import numpy as np
+from numba.typed import Dict as NumbaDict
+from sympy import Symbol
+from sympy.core.function import UndefinedFunction
 
 from ..fields import FieldCollection, VectorField
 from ..fields.base import DataFieldBase, FieldBase
@@ -161,7 +164,7 @@ class PDE(PDEBase):
         else:
             bcs = dict(bc_ops)
             if "*:*" in bcs and bc != "natural":
-                self._logger.warning("Two default boundary conditions.")
+                self._logger.warning("Found default BCs in `bcs` and `bc_ops`")
             bcs["*:*"] = bc  # append default boundary conditions
 
         self.bcs: Dict[str, Any] = {}
@@ -199,6 +202,129 @@ class PDE(PDEBase):
         """show the expressions of the PDE"""
         return {k: v.expression for k, v in self._rhs_expr.items()}
 
+    def _compile_rhs_single(
+        self,
+        var: str,
+        ops: Dict[str, Callable],
+        state: FieldBase,
+        backend: str = "numpy",
+    ):
+        """compile a function determining the right hand side for one variable
+
+        Args:
+            var (str):
+                The variable that is considered
+            ops (dict):
+                A dictionary of operators that can be used by this function. Note that
+                this dictionary might be modified in place
+            state (:class:`~pde.fields.FieldBase`):
+                The field describing the state of the PDE
+            backend (str):
+                The backend for which the data is prepared
+
+        Returns:
+            callable: The function calculating the RHS
+        """
+        # modify a copy of the expression and the general operator array
+        expr = self._rhs_expr[var].copy()
+
+        # obtain the (differential) operators for this variable
+        for func in self._operators[var]:
+            if func in ops:
+                continue
+
+            # determine boundary conditions for this operator and variable
+            for bc_key, bc in self.bcs.items():
+                bc_var, bc_func = bc_key.split(":")
+                var_match = bc_var == var or bc_var == "*"
+                func_match = bc_func == func or bc_func == "*"
+                if var_match and func_match:
+                    break  # found a matching boundary condition
+            else:
+                raise RuntimeError(
+                    "Could not find suitable boundary condition for function "
+                    f"`{func}` applied in equation for `{var}`"
+                )
+
+            # Tell the user what BC we chose for a given operator
+            msg = "Using boundary condition `%s` for operator `%s` in PDE for `%s`"
+            self._logger.info(msg, bc, func, var)
+
+            # create the function evaluating the operator
+            try:
+                ops[func] = state.grid.make_operator(func, bc=bc)
+            except BCDataError:
+                # wrong data was supplied for the boundary condition
+                raise
+            except ValueError:
+                # any other exception should signal that the operator is not
+                # defined, so we (almost) silently assume that sympy defines the
+                # operator
+                self._logger.info(
+                    "Assuming that sympy knows undefined operator `%s`", func
+                )
+
+            # add `bc_args` as an argument to the call of the operators to be able
+            # to pass additional information, like time
+            expr._sympy_expr = expr._sympy_expr.replace(
+                # only modify the relevant operator
+                lambda expr: isinstance(expr.func, UndefinedFunction)
+                and expr.name == func
+                # and do not modify it when the bc_args have already been set
+                and not (
+                    isinstance(expr.args[-1], Symbol)
+                    and expr.args[-1].name == "bc_args"
+                ),
+                # otherwise, add None and bc_args as arguments
+                lambda expr: expr.func(*expr.args, Symbol("none"), Symbol("bc_args")),
+            )
+
+        # obtain the function to calculate the right hand side
+        signature = self.variables + ("t", "none", "bc_args")
+
+        # check whether this function depends on additional input
+        if any(expr.depends_on(c) for c in state.grid.axes):
+            # expression has a spatial dependence, too
+
+            # extend the signature
+            signature += tuple(state.grid.axes)
+            # inject the spatial coordinates into the expression for the rhs
+            extra_args = tuple(  # @UnusedVariable
+                state.grid.cell_coords[..., i] for i in range(state.grid.num_axes)
+            )
+
+        else:
+            # expression only depends on the actual variables
+            extra_args = tuple()  # @UnusedVariable
+
+        # check whether all variables are accounted for
+        extra_vars = set(expr.vars) - set(signature)
+        if extra_vars:
+            extra_vars_str = ", ".join(sorted(extra_vars))
+            raise RuntimeError(f"Undefined variable in expression: {extra_vars_str}")
+        expr.vars = signature
+
+        self._logger.info("RHS for `%s` has signature %s", var, signature)
+
+        # prepare the actual function being called in the end
+        if backend == "numpy":
+            func_inner = expr._get_function(single_arg=False, user_funcs=ops)
+        elif backend == "numba":
+            func_pure = expr._get_function(
+                single_arg=False, user_funcs=ops, prepare_compilation=True
+            )
+            func_inner = jit(func_pure)
+        else:
+            raise ValueError(f"Unsupported backend {backend}")
+
+        def rhs_func(*args) -> np.ndarray:
+            """wrapper that inserts the extra arguments and initialized bc_args"""
+            bc_args = NumbaDict()  # args for differential operators
+            bc_args["t"] = args[-1]  # pass time to differential operators
+            return func_inner(*args, None, bc_args, *extra_args)
+
+        return rhs_func
+
     def _prepare_cache(
         self, state: FieldBase, backend: str = "numpy"
     ) -> Dict[str, Any]:
@@ -210,6 +336,11 @@ class PDE(PDEBase):
         Args:
             state (:class:`~pde.fields.FieldBase`):
                 The field describing the state of the PDE
+            backend (str):
+                The backend for which the data is prepared
+
+        Returns:
+            dict: A dictionary with information that can be reused
         """
         # check the cache
         cache = self._cache.get(backend, {})
@@ -217,6 +348,11 @@ class PDE(PDEBase):
             return cache  # this cache was already prepared
         cache = self._cache[backend] = {}  # clear cache, if there was any
 
+        # check whether PDE has variables with same names as grid axes
+        name_overlap = set(self.rhs) & set(state.grid.axes)
+        if name_overlap:
+            raise ValueError(f"Coordinate {name_overlap} cannot be used as field name")
+
         # check whether the state is compatible with the PDE
         num_fields = len(self.variables)
         self.diagnostics["num_fields"] = num_fields
@@ -264,91 +400,12 @@ class PDE(PDEBase):
             # synonym for dot product operator
             ops_general["outer"] = VectorField(state.grid).make_outer_prod_operator()
 
-        # obtain the python functions for the rhs
-        rhs_funcs = []
-        for var in self.variables:
-            ops = ops_general.copy()
-
-            # obtain the (differential) operators
-            for func in self._operators[var]:
-                if func in ops:
-                    continue
-                # determine boundary conditions
-                for bc_key, bc in self.bcs.items():
-                    bc_var, bc_func = bc_key.split(":")
-                    var_match = bc_var == var or bc_var == "*"
-                    func_match = bc_func == func or bc_func == "*"
-                    if var_match and func_match:
-                        break  # found a matching boundary condition
-                else:
-                    raise RuntimeError(
-                        "Could not find suitable boundary condition for function "
-                        f"`{func}` applied in equation for `{var}`"
-                    )
-
-                # Tell the user what BC we chose for a given operator
-                msg = "Using boundary condition `%s` for operator `%s` in PDE for `%s`"
-                self._logger.info(msg, bc, func, var)
-
-                try:
-                    ops[func] = state.grid.make_operator(func, bc=bc)  # type: ignore
-                except BCDataError:
-                    # wrong data was supplied for the boundary condition
-                    raise
-                except ValueError:
-                    # any other exception should signal that the operator is not defined,
-                    # so we (almost) silently assume that sympy defines the operator
-                    self._logger.info(
-                        "Assuming that sympy knows undefined operator `%s`", func
-                    )
-
-            # obtain the function to calculate the right hand side
-            expr = self._rhs_expr[var]
-            signature = self.variables + ("t",)
-
-            def _get_expr_func(signature: Tuple[str, ...]) -> Callable[..., np.ndarray]:
-                """helper function obtaining expression and checking the signature"""
-                extra_vars = set(expr.vars) - set(signature)
-                if extra_vars:
-                    extra_vars_str = ", ".join(sorted(extra_vars))
-                    raise RuntimeError(
-                        f"Undefined variable in expression: {extra_vars_str}"
-                    )
-                expr.vars = signature
-                if backend == "numpy":
-                    result = expr._get_function(single_arg=False, user_funcs=ops)
-                elif backend == "numba":
-                    result = expr._get_function(
-                        single_arg=False, user_funcs=ops, prepare_compilation=True
-                    )
-                else:
-                    raise ValueError(f"Unsupported backend {backend}")
-                return result  # type: ignore
-
-            if any(expr.depends_on(c) for c in state.grid.axes):
-                # expression has a spatial dependence, too
-
-                # determine and check the signature
-                inner_func = _get_expr_func(signature + tuple(state.grid.axes))
-                if backend == "numba":
-                    inner_func = jit(inner_func)
-
-                # inject the spatial coordinates into the expression for the rhs
-                coords_tuple = tuple(  # @UnusedVariable
-                    state.grid.cell_coords[..., i] for i in range(state.grid.num_axes)
-                )
-
-                def rhs_func(*args) -> np.ndarray:
-                    """wrapper that inserts the spatial variables"""
-                    return inner_func(*args, *coords_tuple)
-
-            else:
-                # expression only depends on the actual variables
-                rhs_func = _get_expr_func(signature)
-
-            rhs_funcs.append(rhs_func)
-
-        cache["rhs_funcs"] = rhs_funcs
+        # Create the right hand sides for all variables. It is important to do this in a
+        # separate function, so the closures work reliably
+        cache["rhs_funcs"] = [
+            self._compile_rhs_single(var, ops_general.copy(), state, backend)
+            for var in self.variables
+        ]
 
         # add extra information for field collection
         if isinstance(state, FieldCollection):
