@@ -54,11 +54,6 @@ harmonics, where the order is always zero and the degree :math:`l` and the mode
    radius_from_volume
    volume_from_radius
    surface_from_radius
-   points_cartesian_to_spherical
-   points_spherical_to_cartesian
-   haversine_distance
-   get_spherical_polygon_area
-   PointsOnSphere
    spherical_index_k
    spherical_index_lm
    spherical_index_count
@@ -96,11 +91,11 @@ def radius_from_volume(volume: TNumArr, dim: int) -> TNumArr:
         float or :class:`~numpy.ndarray`: Radius of the sphere
     """
     if dim == 1:
-        return volume / 2
+        return volume / 2  # type: ignore
     elif dim == 2:
         return np.sqrt(volume / π)  # type: ignore
     elif dim == 3:
-        return (3 * volume / (4 * π)) ** (1 / 3)
+        return (3 * volume / (4 * π)) ** (1 / 3)  # type: ignore
     else:
         raise NotImplementedError(f"Cannot calculate the radius in {dim} dimensions")
 
@@ -145,11 +140,11 @@ def volume_from_radius(radius: TNumArr, dim: int) -> TNumArr:
         float or :class:`~numpy.ndarray`: Volume of the sphere
     """
     if dim == 1:
-        return 2 * radius
+        return 2 * radius  # type: ignore
     elif dim == 2:
-        return π * radius ** 2
+        return π * radius ** 2  # type: ignore
     elif dim == 3:
-        return 4 * π / 3 * radius ** 3
+        return 4 * π / 3 * radius ** 3  # type: ignore
     else:
         raise NotImplementedError(f"Cannot calculate the volume in {dim} dimensions")
 
@@ -166,17 +161,17 @@ def make_volume_from_radius_compiled(dim: int) -> Callable[[TNumArr], TNumArr]:
     if dim == 1:
 
         def volume_from_radius(radius: TNumArr) -> TNumArr:
-            return 2 * radius
+            return 2 * radius  # type: ignore
 
     elif dim == 2:
 
         def volume_from_radius(radius: TNumArr) -> TNumArr:
-            return π * radius ** 2
+            return π * radius ** 2  # type: ignore
 
     elif dim == 3:
 
         def volume_from_radius(radius: TNumArr) -> TNumArr:
-            return 4 * π / 3 * radius ** 3
+            return 4 * π / 3 * radius ** 3  # type: ignore
 
     else:
         raise NotImplementedError(f"Cannot calculate the volume in {dim} dimensions")
@@ -199,9 +194,9 @@ def surface_from_radius(radius: TNumArr, dim: int) -> TNumArr:
         else:
             return 2
     elif dim == 2:
-        return 2 * π * radius
+        return 2 * π * radius  # type: ignore
     elif dim == 3:
-        return 4 * π * radius ** 2
+        return 4 * π * radius ** 2  # type: ignore
     else:
         raise NotImplementedError(
             f"Cannot calculate the surface area in {dim} dimensions"
@@ -221,7 +216,7 @@ def radius_from_surface(surface: TNumArr, dim: int) -> TNumArr:
     if dim == 1:
         raise RuntimeError("Cannot calculate radius of 1-d sphere from surface")
     elif dim == 2:
-        return surface / (2 * π)
+        return surface / (2 * π)  # type: ignore
     elif dim == 3:
         return np.sqrt(surface / (4 * π))  # type: ignore
     else:
@@ -262,13 +257,13 @@ def make_surface_from_radius_compiled(dim: int) -> Callable[[TNumArr], TNumArr]:
 
         @jit
         def surface_from_radius(radius: TNumArr) -> TNumArr:
-            return 2 * π * radius
+            return 2 * π * radius  # type: ignore
 
     elif dim == 3:
 
         @jit
         def surface_from_radius(radius: TNumArr) -> TNumArr:
-            return 4 * π * radius ** 2
+            return 4 * π * radius ** 2  # type: ignore
 
     else:
         raise NotImplementedError(
@@ -559,7 +554,7 @@ class PointsOnSphere:
         """write the point coordinates to a xyz file
 
         Args:
-            filename (str): location of the file where data is written
+            path (str): location of the file where data is written
             comment (str, optional): comment that is written to the second line
             symbol (str, optional): denotes the symbol used for the atoms
         """
@@ -610,7 +605,7 @@ def spherical_index_count(l: int) -> int:
     The returned value is one less than the maximal mode `k` required.
 
     Args:
-        degree (int): Maximal degree of the spherical harmonics
+        l (int): Maximal degree of the spherical harmonics
 
     Returns:
         int: The number of modes
