@@ -13,7 +13,7 @@ PACKAGE_PATH = Path(__file__).resolve().parents[1]
 
 @dataclass
 class Requirement:
-    """ simple class collecting data for a single required python package """
+    """simple class collecting data for a single required python package"""
 
     name: str  # name of the python package
     version: str  # minimal version
@@ -73,6 +73,9 @@ REQUIREMENTS = [
         for_docs=True,
         for_tests=True,
     ),
+    Requirement(
+        name="ipywidgets", version="7", usage="Jupyter notebook support", optional=True
+    ),
     Requirement(
         name="napari",
         version="0.4",
@@ -102,11 +105,13 @@ REQUIREMENTS = [
         for_tests=True,
     ),
     # for documentation only
+    Requirement(name="Sphinx", version="4", for_docs=True),
     Requirement(name="sphinx-autodoc-annotation", version="1.0", for_docs=True),
     Requirement(name="sphinx-gallery", version="0.6", for_docs=True),
     Requirement(name="sphinx-rtd-theme", version="0.4", for_docs=True),
     Requirement(name="Pillow", version="7.0", for_docs=True),
     # for tests only
+    Requirement(name="jupyter_contrib_nbextensions", version="0.5", for_tests=True),
     Requirement(name="black", version="19.*", for_tests=True),
     Requirement(name="isort", version="5.1", for_tests=True),
     Requirement(name="mypy", version="0.770", for_tests=True),
@@ -169,17 +174,49 @@ def write_requirements_csv(
                 writer.writerow([r.name, r.usage])
 
 
+def write_requirements_py(path: Path, requirements: List[Requirement]):
+    """write requirements check into a python module
+
+    Args:
+        path (:class:`Path`): The path where the requirements are written
+        requirements (list): The requirements to be written
+    """
+    print(f"Modify `{path}`")
+
+    # read user-created content of file
+    content = []
+    with open(path, "r") as fp:
+        for line in fp:
+            if "GENERATED CODE" in line:
+                content.append(line)
+                break
+            content.append(line)
+        else:
+            raise ValueError("Could not find the token 'GENERATED CODE'")
+
+    # add generated code
+    for r in sorted(requirements, key=lambda r: r.name.lower()):
+        content.append(f'check_package_version("{r.name}", "{r.version}")\n')
+    content.append("del check_package_version\n")
+
+    # write content back to file
+    with open(path, "w") as fp:
+        fp.writelines(content)
+
+
 def main():
-    """ main function creating all the requirements """
+    """main function creating all the requirements"""
+    root = Path(PACKAGE_PATH)
+
     # write basic requirements
     write_requirements_txt(
-        Path(PACKAGE_PATH) / "requirements.txt",
+        root / "requirements.txt",
         [r for r in REQUIREMENTS if r.essential],
     )
 
     # write minimal requirements to tests folder
     write_requirements_txt(
-        Path(PACKAGE_PATH) / "tests" / "requirements_min.txt",
+        root / "tests" / "requirements_min.txt",
         [r for r in REQUIREMENTS if r.essential],
         rel="~=",
         comment="These are the minimal requirements used to test compatibility",
@@ -187,35 +224,37 @@ def main():
 
     # write requirements to docs folder
     write_requirements_txt(
-        Path(PACKAGE_PATH) / "docs" / "requirements.txt",
+        root / "docs" / "requirements.txt",
         [r for r in REQUIREMENTS if r.for_docs],
         ref_base=True,
     )
 
     # write requirements to docs folder
     write_requirements_txt(
-        Path(PACKAGE_PATH) / "tests" / "requirements.txt",
+        root / "tests" / "requirements.txt",
         [r for r in REQUIREMENTS if r.for_tests],
         ref_base=True,
     )
 
     # write requirements for documentation as CSV
     write_requirements_csv(
-        Path(PACKAGE_PATH) / "docs" / "source" / "_static" / "requirements_main.csv",
+        root / "docs" / "source" / "_static" / "requirements_main.csv",
         [r for r in REQUIREMENTS if r.essential],
     )
 
     # write requirements for documentation as CSV
     write_requirements_csv(
-        Path(PACKAGE_PATH)
-        / "docs"
-        / "source"
-        / "_static"
-        / "requirements_optional.csv",
+        root / "docs" / "source" / "_static" / "requirements_optional.csv",
         [r for r in REQUIREMENTS if r.optional],
         incl_version=False,
     )
 
+    # write version.py
+    write_requirements_py(
+        root / "pde" / "__init__.py",
+        [r for r in REQUIREMENTS if r.essential],
+    )
+
 
 if __name__ == "__main__":
     main()
