@@ -8,29 +8,29 @@ import sys
 from pathlib import Path
 
 PACKAGE_PATH = Path(__file__).resolve().parents[1]
-sys.path.append(str(PACKAGE_PATH))
+sys.path.insert(0, str(PACKAGE_PATH))
 
-import numba
+import numba as nb
 import numpy as np
 
-from pde import config
-from pde.grids import CylindricalGrid, SphericalGrid, UnitGrid
+from pde import CylindricalSymGrid, ScalarField, SphericalSymGrid, UnitGrid, config
 from pde.grids.boundaries import Boundaries
-from pde.grids.operators import cartesian, cylindrical, spherical
 from pde.tools.misc import estimate_computation_speed
 from pde.tools.numba import jit, jit_allocate_out
 
+config["numba.parallel"] = False
+
 
 def custom_laplace_2d_periodic(shape, dx=1):
-    """ make laplace operator with periodic boundary conditions """
+    """make laplace operator with periodic boundary conditions"""
     dx_2 = 1 / dx ** 2
     dim_x, dim_y = shape
     parallel = dim_x * dim_y >= config["numba.parallel_threshold"]
 
     @jit_allocate_out(parallel=parallel)
-    def laplace(arr, out=None):
-        """ apply laplace operator to array `arr` """
-        for i in numba.prange(dim_x):
+    def laplace(arr, out=None, args=None):
+        """apply laplace operator to array `arr`"""
+        for i in nb.prange(dim_x):
             im = dim_x - 1 if i == 0 else i - 1
             ip = 0 if i == dim_x - 1 else i + 1
 
@@ -57,15 +57,15 @@ def custom_laplace_2d_periodic(shape, dx=1):
 
 
 def custom_laplace_2d_neumann(shape, dx=1):
-    """ make laplace operator with Neumann boundary conditions """
+    """make laplace operator with Neumann boundary conditions"""
     dx_2 = 1 / dx ** 2
     dim_x, dim_y = shape
     parallel = dim_x * dim_y >= config["numba.parallel_threshold"]
 
     @jit_allocate_out(parallel=parallel)
-    def laplace(arr, out=None):
-        """ apply laplace operator to array `arr` """
-        for i in numba.prange(dim_x):
+    def laplace(arr, out=None, args=None):
+        """apply laplace operator to array `arr`"""
+        for i in nb.prange(dim_x):
             im = 0 if i == 0 else i - 1
             ip = dim_x - 1 if i == dim_x - 1 else i + 1
 
@@ -81,7 +81,7 @@ def custom_laplace_2d_neumann(shape, dx=1):
 
 
 def custom_laplace_2d(shape, periodic, dx=1):
-    """ make laplace operator with Neumann or periodic boundary conditions """
+    """make laplace operator with Neumann or periodic boundary conditions"""
     if periodic:
         return custom_laplace_2d_periodic(shape, dx=dx)
     else:
@@ -89,19 +89,21 @@ def custom_laplace_2d(shape, periodic, dx=1):
 
 
 def flexible_laplace_2d(bcs):
-    """ make laplace operator with flexible boundary conditions """
+    """make laplace operator with flexible boundary conditions"""
     bc_x, bc_y = bcs
-    dx = bcs._uniform_discretization
+    dx = np.mean(bcs.grid.discretization)
     dx_2 = 1 / dx ** 2
     dim_x, dim_y = bcs.grid.shape
 
     region_x = bc_x.make_region_evaluator()
     region_y = bc_y.make_region_evaluator()
 
-    @jit_allocate_out
-    def laplace(arr, out=None):
-        """ apply laplace operator to array `arr` """
-        for i in range(dim_x):
+    parallel = dim_x * dim_y >= config["numba.parallel_threshold"]
+
+    @jit_allocate_out(parallel=parallel)
+    def laplace(arr, out=None, args=None):
+        """apply laplace operator to array `arr`"""
+        for i in nb.prange(dim_x):
             for j in range(dim_y):
                 val_x_l, val_x, val_x_r = region_x(arr, (i, j))
                 val_y_l, _, val_y_r = region_y(arr, (i, j))
@@ -112,15 +114,32 @@ def flexible_laplace_2d(bcs):
     return laplace
 
 
+def optimized_laplace_2d(bcs):
+    """make laplace operator with flexible boundary conditions"""
+    set_ghost_cells = bcs.make_ghost_cell_setter()
+    apply_laplace = bcs.grid.make_operator_no_bc("laplace")
+    shape = bcs.grid.shape
+
+    @jit
+    def laplace(arr):
+        """apply laplace operator to array `arr`"""
+        set_ghost_cells(arr)
+        out = np.empty(shape)
+        apply_laplace(arr, out)
+        return out
+
+    return laplace
+
+
 def custom_laplace_cyl_neumann(shape, dr=1, dz=1):
-    """ make laplace operator with Neumann boundary conditions """
+    """make laplace operator with Neumann boundary conditions"""
     dim_r, dim_z = shape
     dr_2 = 1 / dr ** 2
     dz_2 = 1 / dz ** 2
 
     @jit
     def laplace(arr, out=None):
-        """ apply laplace operator to array `arr` """
+        """apply laplace operator to array `arr`"""
         if out is None:
             out = np.empty((dim_r, dim_z))
 
@@ -155,7 +174,7 @@ def custom_laplace_cyl_neumann(shape, dr=1, dz=1):
 
 
 def main():
-    """ main routine testing the performance """
+    """main routine testing the performance"""
     print("Reports calls-per-second (larger is better)")
     print("  The `CUSTOM` method implemented by hand is the baseline case.")
     print(
@@ -166,63 +185,68 @@ def main():
 
     # Cartesian grid with different shapes and boundary conditions
     for shape in [(32, 32), (512, 512)]:
-        data = np.random.random(shape)
         for periodic in [True, False]:
             grid = UnitGrid(shape, periodic=periodic)
-            bcs = Boundaries.from_data(grid, "natural")
             print(grid)
-            result = cartesian.make_laplace(bcs, method="scipy")(data)
+            field = ScalarField.random_normal(grid)
+            bcs = grid.get_boundary_conditions("natural", rank=0)
+            expected = field.laplace("natural")
 
-            for method in ["FLEXIBLE", "CUSTOM", "numba", "matrix", "scipy"]:
-                if method == "FLEXIBLE":
-                    laplace = flexible_laplace_2d(bcs)
-                elif method == "CUSTOM":
+            for method in ["CUSTOM", "FLEXIBLE", "OPTIMIZED", "numba", "scipy"]:
+                if method == "CUSTOM":
                     laplace = custom_laplace_2d(shape, periodic=periodic)
-                elif method in {"numba", "matrix", "scipy"}:
-                    laplace = cartesian.make_laplace(bcs, method=method)
+                elif method == "FLEXIBLE":
+                    laplace = flexible_laplace_2d(bcs)
+                elif method == "OPTIMIZED":
+                    laplace = optimized_laplace_2d(bcs)
+                elif method in {"numba", "scipy"}:
+                    laplace = grid.make_operator("laplace", bc=bcs, backend=method)
                 else:
                     raise ValueError(f"Unknown method `{method}`")
+
                 # call once to pre-compile and test result
-                np.testing.assert_allclose(laplace(data), result)
-                speed = estimate_computation_speed(laplace, data)
-                print(f"{method:>8s}: {int(speed):>9d}")
+                if method == "OPTIMIZED":
+                    result = laplace(field._data_full)
+                    np.testing.assert_allclose(result, expected.data)
+                    speed = estimate_computation_speed(laplace, field._data_full)
+                else:
+                    np.testing.assert_allclose(laplace(field.data), expected.data)
+                    speed = estimate_computation_speed(laplace, field.data)
+                print(f"{method:>9s}: {int(speed):>9d}")
             print()
 
     # Cylindrical grid with different shapes
     for shape in [(32, 64), (512, 512)]:
-        data = np.random.random(shape)
-        grid = CylindricalGrid(shape[0], [0, shape[1]], shape)
+        grid = CylindricalSymGrid(shape[0], [0, shape[1]], shape)
         print(f"Cylindrical grid, shape={shape}")
+        field = ScalarField.random_normal(grid)
         bcs = Boundaries.from_data(grid, "derivative")
-        laplace_cyl = cylindrical.make_laplace(bcs)
-        result = laplace_cyl(data)
+        expected = field.laplace(bcs)
 
         for method in ["CUSTOM", "numba"]:
             if method == "CUSTOM":
                 laplace = custom_laplace_cyl_neumann(shape)
             elif method == "numba":
-                laplace = laplace_cyl
+                laplace = grid.make_operator("laplace", bc=bcs)
             else:
                 raise ValueError(f"Unknown method `{method}`")
             # call once to pre-compile and test result
-            np.testing.assert_allclose(laplace(data), result)
-            speed = estimate_computation_speed(laplace, data)
+            np.testing.assert_allclose(laplace(field.data), expected.data)
+            speed = estimate_computation_speed(laplace, field.data)
             print(f"{method:>8s}: {int(speed):>9d}")
         print()
 
     # Spherical grid with different shapes
     for shape in [32, 512]:
-        data = np.random.random(shape)
-        grid = SphericalGrid(shape, shape)
+        grid = SphericalSymGrid(shape, shape)
         print(grid)
+        field = ScalarField.random_normal(grid)
         bcs = Boundaries.from_data(grid, "derivative")
-        make_laplace = spherical.make_laplace
 
         for conservative in [True, False]:
-            laplace = make_laplace(bcs, conservative=conservative)
-            # call once to pre-compile
-            laplace(data)
-            speed = estimate_computation_speed(laplace, data)
+            laplace = grid.make_operator("laplace", bcs, conservative=conservative)
+            laplace(field.data)  # call once to pre-compile
+            speed = estimate_computation_speed(laplace, field.data)
             print(f" numba (conservative={str(conservative):<5}): {int(speed):>9d}")
         print()
 
